@@ -1,3 +1,3 @@
 if __name__ == '__main__':
-    from run import run
+    from .run import run
     run()
\ No newline at end of file
