@@ -1,10 +1,11 @@
+from gview import plotDataAPI
 from .app_celery_init import create_app
 
 # initialize app
 app = create_app()
 
 # resgister blueprints
-import index,host
+from . import index,host,plotDataAPI
 app.register_blueprint(index.bp)
 app.register_blueprint(host.bp)
-
+app.register_blueprint(plotDataAPI.bp)
