@@ -20,6 +20,7 @@ def periodicUpdateData(sender, **kwargs):
 # load and update plot data
 @celery.task()
 def updateHostsData():
+    requestTime = int(round(time.time()*1000))
     hosts = load_hosts()
     gpustats = []
 
@@ -60,7 +61,7 @@ def updateHostsData():
     with open(os.path.join(R_PATH,'static/js/HostData.json'), 'r') as f:
         gpuJSON = json.load(f)
     
-    gpuJSON.append({int(round(time.time()*1000)):gpustats})
+    gpuJSON.append({requestTime:gpustats})
 
     # only keep the last week data 
     if len(gpuJSON) > 10080:
